pub struct BybitApiKeyPermissions {Show 18 fields
pub contract_trade: Vec<String>,
pub spot: Vec<String>,
pub wallet: Vec<String>,
pub options: Vec<String>,
pub derivatives: Vec<String>,
pub exchange: Vec<String>,
pub copy_trading: Vec<String>,
pub block_trade: Vec<String>,
pub nft: Vec<String>,
pub affiliate: Vec<String>,
pub earn: Vec<String>,
pub fiat_p2p: Vec<String>,
pub fiat_bybit_pay: Vec<String>,
pub fiat_bit_pay: Vec<String>,
pub fiat_global_pay: Vec<String>,
pub fiat_convert_broker: Vec<String>,
pub bit_card: Vec<String>,
pub byx_post: Vec<String>,
}Expand description
API key permissions.
Fields
contract_trade: Vec<String>spot: Vec<String>wallet: Vec<String>options: Vec<String>derivatives: Vec<String>exchange: Vec<String>copy_trading: Vec<String>block_trade: Vec<String>nft: Vec<String>affiliate: Vec<String>earn: Vec<String>fiat_p2p: Vec<String>fiat_bybit_pay: Vec<String>fiat_bit_pay: Vec<String>fiat_global_pay: Vec<String>fiat_convert_broker: Vec<String>bit_card: Vec<String>byx_post: Vec<String>Trait Implementations
Sourceimpl Clone for BybitApiKeyPermissions
impl Clone for BybitApiKeyPermissions
Sourcefn clone(&self) -> BybitApiKeyPermissions
fn clone(&self) -> BybitApiKeyPermissions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BybitApiKeyPermissions
impl Debug for BybitApiKeyPermissions
Sourceimpl<'de> Deserialize<'de> for BybitApiKeyPermissions
impl<'de> Deserialize<'de> for BybitApiKeyPermissions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for BybitApiKeyPermissionswhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for BybitApiKeyPermissionswhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for BybitApiKeyPermissions
impl<'py> IntoPyObject<'py> for BybitApiKeyPermissions
Sourcetype Target = BybitApiKeyPermissions
type Target = BybitApiKeyPermissions
The Python output type
Sourcetype Output = Bound<'py, <BybitApiKeyPermissions as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <BybitApiKeyPermissions as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for BybitApiKeyPermissions
impl PyClass for BybitApiKeyPermissions
Sourceimpl PyClassImpl for BybitApiKeyPermissions
impl PyClassImpl for BybitApiKeyPermissions
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// API key permissions.
const RAW_DOC: &'static CStr = /// API key permissions.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<BybitApiKeyPermissions as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<BybitApiKeyPermissions>
type Layout = <<BybitApiKeyPermissions as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<BybitApiKeyPermissions>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForBybitApiKeyPermissions
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyStubType for BybitApiKeyPermissions
impl PyStubType for BybitApiKeyPermissions
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
fn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for BybitApiKeyPermissions
impl PyTypeInfo for BybitApiKeyPermissions
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for BybitApiKeyPermissions
impl Serialize for BybitApiKeyPermissions
impl DerefToPyAny for BybitApiKeyPermissions